@@ -156,6 +156,19 @@ Author: w.x.chan@gmail.com    21Jul2021                - v2.8.3   replace tab by
                         -BsplineFourier version 2.7.14
                         -motionCorrect version 2.7.8
                         -segment verion 2.7.19
+Author: w.x.chan@gmail.com    21Jul2021                - v2.8.6   
+                                -debug maskImg remained as False 
+                        -bfSolver version 2.8.0
+                        -BsplineFourier version 2.7.14
+                        -motionCorrect version 2.7.8
+                        -segment verion 2.7.19
+Author: w.x.chan@gmail.com    04Aug2021                - v2.8.7   
+                                -added imgfmt to simpleSolver 
+                                - added automatic anchor
+                        -bfSolver version 2.8.0
+                        -BsplineFourier version 2.7.14
+                        -motionCorrect version 2.7.8
+                        -segment verion 2.7.19
 Requirements:
     autoD
     numpy
@@ -169,7 +182,7 @@ Known Bug:
     HSV color format not supported
 All rights reserved.
 '''
-_version='2.8.5'
+_version='2.8.7'
 import logging
 logger = logging.getLogger('motionSegmentation v'+_version)
 logger.info('motionSegmentation version '+_version)
@@ -186,7 +199,7 @@ import medImgProc as mip
 import medImgProc.processFunc as pf
 import time
 
-def simpleSolver(savePath,startstep=1,endstep=7,fileScale=None,getCompoundTimeList=None,compoundSchemeList=None,fftLagrangian=True,pngFileFormat=None,period=None,maskImg=True,anchor=None,bgrid=4.,finalShape=None,fourierTerms=4,twoD=False):
+def simpleSolver(savePath,startstep=1,endstep=7,fileScale=None,getCompoundTimeList=None,compoundSchemeList=None,fftLagrangian=True,pngFileFormat=None,period=None,maskImg=True,anchor=None,bgrid=4.,finalShape=None,fourierTerms=4,twoD=False,imgfmt=None):
     '''
     step 1: load image
     step 2: create mask
@@ -240,6 +253,8 @@ def simpleSolver(savePath,startstep=1,endstep=7,fileScale=None,getCompoundTimeLi
             image.dimlen['z']=imagedim[2]
             image.dimlen['t']=1.
             image.rearrangeDim(['t','z','y','x'])
+        if imgfmt is not None:
+            image.data=image.data.astype(imgfmt)
         image.save(savePath+'/img')
         
     if startstep<=2 and endstep>=2:
@@ -289,6 +304,8 @@ def simpleSolver(savePath,startstep=1,endstep=7,fileScale=None,getCompoundTimeLi
                 maskImg=mip.load(savePath+'/'+maskImg).data
             else:
                 maskImg=mip.load(savePath+'/maskBorderImg').data.astype(float)
+        else:
+            maskImg=None
         startTime=time.process_time()
         if twoD:
             setOrigin=(0.,0.)
@@ -298,6 +315,12 @@ def simpleSolver(savePath,startstep=1,endstep=7,fileScale=None,getCompoundTimeLi
             pf.TmapRegister(image,savePath=savePath,origin=setOrigin,bgrid=bgrid,bweight=1.,rms=True,startTime=0,scaleImg=fileScale,maskArray=maskImg,twoD=twoD,cyclic=False)
         else:
             pf.TmapRegister(image,savePath=savePath,origin=setOrigin,bgrid=bgrid,bweight=1.,rms=True,startTime=0,scaleImg=fileScale,maskArray=maskImg,twoD=twoD,cyclic=True)
+        if anchor is not None:
+            for n in range(len(anchor)):
+                if len(anchor[n])==4:
+                    image1=mip.load(anchor[n][2])
+                    image2=mip.load(anchor[n][3])
+                    pf.TmapRegister_img2img(image1,image2,savePath=savePath,fileName='manual_'+regfile_general[:-4].format(anchor[n][0],anchor[n][1]),scaleImg=fileScale)
         regTime=time.process_time()-startTime
         allTime.append(regTime)
         allTimeHeader+="registrationTime,"
@@ -380,9 +403,11 @@ def simpleSolver(savePath,startstep=1,endstep=7,fileScale=None,getCompoundTimeLi
             solver.addBsplineFile(fileList,timeMapList=timeMapList,fileScale=fileScale)
         fft_bsFourier=BsplineFourier.BsplineFourier(savePath+'/'+saveName+'_fft.txt')
         for n in range(len(anchor)):
-            solver.addBsplineFile(imregPath+'manual_'+regfile_general.format(anchor[n][0],anchor[n][1]),timeMapList=[timeList[anchor[n][0]],timeList[anchor[n][1]]],weightList=10.,fileScale=fileScale)
-    
-        
+            if len(anchor[n])==3:
+                solver.addBsplineFile(anchor[n][2],timeMapList=[timeList[anchor[n][0]],timeList[anchor[n][1]]],weightList=10.,fileScale=fileScale)
+            else:
+                solver.addBsplineFile(imregPath+'manual_'+regfile_general.format(anchor[n][0],anchor[n][1]),timeMapList=[timeList[anchor[n][0]],timeList[anchor[n][1]]],weightList=10.,fileScale=fileScale)
+                
         solver.bsFourier=fft_bsFourier
         if type(finalShape)!=type(None):
             if np.any(np.array(finalShape)!=np.array(solver.bsFourier.coef.shape)):
